const { trim } = require("lodash");

(function ($) {
  "use strict";
  $(function () {
    let servers = JSON.parse($("#servers").text());
    let options = JSON.parse($("#options").text());
    let map = null;

    let resultsFetched = 0;

    $(document).ready(function () {
      let hashes = getHash();
      if (!jQuery.isEmptyObject(hashes)) {
        $("#type").val(hashes.type);
        $("#domain").val(hashes.domain);
        $("#input input[type=submit]").val(". . .");
        $("#input input[type=submit]").attr("disabled", true);
        for (let i = 0; i < servers.length; i++) {
          getResults(i, servers[i].id, hashes.type, hashes.domain);
        }
      }
    });

    if ($("#map").length > 0) {
      $("#map").vectorMap({
        map: "world_mill",
        zoomOnScroll: !1,
        zoomButtons: !1,
        normalizeFunction: "polynomial",
        hoverOpacity: 0.7,
        hoverColor: false,
        markerStyle: {
          initial: {
            fill: "#FFF",
            stroke: "#FFF",
          },
        },
        backgroundColor: "transparent",
        regionStyle: {
          initial: {
            fill: options["colors"]["primary"],
            stroke: options["colors"]["primary"],
            "stroke-width": 1,
            "stroke-opacity": 1,
          },
          hover: {
            "fill-opacity": 1,
            cursor: "default",
          },
        },
        markers: servers.map(function (s) {
          return { name: s.name, latLng: [s.lat, s.long] };
        }),
        onMarkerTipShow: function (e, el, index) {
          var html = '<div class="name"><img width="16px" src="/images/flags/' + servers[index].country.toLowerCase() + '.svg"> ' + servers[index].name + "</div>";
          servers[index].result && (html += '<div class="result">' + servers[index].result + "</div>"), el.html(html);
        },
        onRegionTipShow: function (e) {
          e.preventDefault();
        },
      });
      map = $("#map").vectorMap("get", "mapObject");
      clearResults();
    }

    $("#input").on("submit", (e) => {
      e.preventDefault();
      clearResults();
      $("#input input[type=submit]").val(". . .");
      $("#input input[type=submit]").attr("disabled", true);
      let expected = $("#expected").val();
      let domain = $("#domain").val();
      domain = domain.replace("http://", "").replace("https://", "").split(/[/?#]/)[0];
      $("#domain").val(domain);
      let type = $("#type").val();
      setHash(domain, type);
      for (let i = 0; i < servers.length; i++) {
        getResults(i, servers[i].id, type, domain, expected);
      }
      map.reset();
    });

    function getResults(key, id, type, domain, expected) {
      $.ajax({
        url: `fetch/${domain}/${type}/${id}`,
        type: "POST",
        data: {
          _token: document.querySelector('meta[name="csrf-token"]').getAttribute("content"),
        },
        success: function (data) {
          if (data) {
            $("#server-" + id + " .result").html(data);
            servers[key].result = data;
            if (map) {
              if (expected != undefined && expected != "" && expected != data) {
                $("#server-" + id + " .status img").attr("src", errorImg);
                map.markers[key].element.config.style.current.image = errorImg;
              } else {
                $("#server-" + id + " .status img").attr("src", successImg);
                map.markers[key].element.config.style.current.image = successImg;
              }
            }
          } else {
            $("#server-" + id + " .status img").attr("src", errorImg);
            servers[key].result = "";
            if (map) {
              map.markers[key].element.config.style.current.image = errorImg;
            }
          }
          resultsFetched++;
          map.reset();
          if (resultsFetched === servers.length) {
            $("#input input[type=submit]").val("Find");
            $("#input input[type=submit]").removeAttr("disabled");
          }
        },
        error: function (data) {
          console.error(`Error on: ${servers[key].name} with message ${data}`);
          $("#server-" + id + " .status img").attr("src", errorImg);
          if (map) {
            map.markers[key].element.config.style.current.image = errorImg;
          }
          resultsFetched++;
          map.reset();
          if (resultsFetched === servers.length) {
            $("#input input[type=submit]").val(options.find_btn.text);
            $("#input input[type=submit]").removeAttr("disabled");
          }
        },
        timeout: options["timeout"] ? options["timeout"] * 1000 : 5000,
      });
    }

    function clearResults() {
      resultsFetched = 0;
      for (let i = 0; i < servers.length; i++) {
        $("#server-" + servers[i].id + " .result").html("");
        $("#server-" + servers[i].id + " .status img").attr("src", pendingImg);
        if (map) {
          map.markers[i].element.config.style.current.image = pendingImg;
        }
        map.reset();
      }
    }

    function setHash(domain, type) {
      location.hash = `#/${type}/${domain}`;
    }

    function getHash() {
      const hashes = location.hash.split("/");
      if (hashes[2] !== undefined && hashes[1] !== undefined) {
        return {
          domain: hashes[2],
          type: hashes[1],
        };
      } else {
        return {};
      }
    }
  });
})(jQuery);

//Reload if 100 minutes are passed
let start = new Date();
setInterval(() => {
  if ((new Date() - start) / (1000 * 60) > 100) {
    location.reload();
  }
}, 1000);

if (typeof Shortcode !== "undefined") {
  new Shortcode(document.querySelector("body"), {
    blogs: function () {
      var data = '<div class="blogs row">';
      var fetchUrl = this.options.url + "/wp-json/wp/v2/posts?_fields[]=link&_fields[]=title&_fields[]=excerpt";
      var filters = {
        context: this.options.context,
        page: this.options.page,
        per_page: this.options.per_page,
        search: this.options.search,
        after: this.options.after,
        author: this.options.author,
        author_exclude: this.options.author_exclude,
        before: this.options.before,
        exclude: this.options.exclude,
        include: this.options.include,
        offset: this.options.offset,
        order: this.options.order,
        orderby: this.options.orderby,
        slug: this.options.slug,
        status: this.options.status,
        categories: this.options.categories,
        categories_exclude: this.options.categories_exclude,
        tags: this.options.tags,
        tags_exclude: this.options.tags_exclude,
        sticky: this.options.sticky,
      };
      Object.keys(filters).forEach(function (key) {
        if (filters[key]) {
          fetchUrl += "&" + key + "=" + filters[key];
        }
      });
      fetch(fetchUrl)
        .then((response) => response.json())
        .then((blogs) => {
          blogs.forEach(function (item) {
            data += '<div class="blog-item col-md-6">';
            data += '<a href="' + item.link + '" target="_blank">';
            data += '<span class="title">' + item.title.rendered + "</span>";
            data += '<span class="excerpt">' + item.excerpt.rendered + "</span>";
            data += "</a>";
            data += "</div>";
          });
          data += "</div>";
          if (blogs.length) {
            document.getElementById("blogs").innerHTML = data;
          } else {
            document.getElementById("blogs").innerHTML = '<div class="no-content">204 - NO CONTENT AVAILABLE</div>';
          }
        });
      return "<div id='blogs'><div class='content-loader'><div class='spinner-border' role='status'><span class='sr-only'>Loading...</span></div></div>";
    },
    html: function () {
      let txt = document.createElement("textarea");
      txt.innerHTML = this.contents;
      return txt.value;
    },
    contact_form: function () {
      let captcha_html = "";
      let button_attributes = "type='submit'";
      if (captcha_name && captcha_name !== "off") {
        if (captcha_name == "recaptcha2" || captcha_name == "hcaptcha") {
          captcha_html = `<div class="g-recaptcha" data-sitekey="${site_key}"></div>`;
        } else if (captcha_name == "recaptcha3") {
          button_attributes = `class="g-recaptcha" data-sitekey="${site_key}" data-callback='submitContactForm' data-action='submit'`;
        }
      }
      let html = `
        <form class="contact-form pt-5 flex flex-col gap-3" action="/widget/contact" method="post">
          <input type="hidden" name="_token" value="${document.querySelector('meta[name="csrf-token"]').content}" />
          <div class="flex flex-col md:flex-row items-center gap-3">
            <div class="w-full">
              <label class="block mb-1" for="your_name">Your Name</label>
              <input class="form-input rounded-md block w-full border" type="text" name="your_name" id="your_name" placeholder="Enter your Name" required>
            </div>
            <div class="w-full">
              <label class="block mb-1" for="your_email">Your Email</label>
              <input class="form-input rounded-md block w-full border" type="email" name="your_email" id="your_email" placeholder="Enter your Email" required>
            </div>
          </div>
          <div>
            <label class="block mb-1" for="your_message">Message</label>
            <textarea class="form-input rounded-md block w-full border" name="your_message" id="your_message" placeholder="Enter your Message" required></textarea>
          </div>
          ${captcha_html}
          <button class="form-input rounded-md block w-full border-0 bg-primary text-white" ${button_attributes}>Send Message</button>
        </form>
        `;
      return html;
    },
  });
}

const submitContactForm = () => {
  document.querySelector(".contact-form").submit();
};

document.addEventListener("showAlert", (type) => {
  let icons = {
    error: '<div class="text-red-500 w-10"> <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke="currentColor"> <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M10 14l2-2m0 0l2-2m-2 2l-2-2m2 2l2 2m7-2a9 9 0 11-18 0 9 9 0 0118 0z"/> </svg> </div>',
    success: '<div class="text-green-500 w-10"> <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke="currentColor"> <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M9 12l2 2 4-4m6 2a9 9 0 11-18 0 9 9 0 0118 0z"/> </svg> </div>',
    warning: '<div class="text-yellow-500 w-10"> <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke="currentColor"> <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M12 8v4m0 4h.01M21 12a9 9 0 11-18 0 9 9 0 0118 0z"/> </svg> </div>',
  };
  let shades = {
    success: "bg-green-50 border-green-500",
    error: "bg-red-50 border-red-500",
    warning: "bg-yellow-50 border-yellow-500",
  };
  let el = document.createElement("div");
  el.innerHTML = `
    <div x-data="{ open: false }" x-init="() => { setTimeout(() => { open = true }, 100); setTimeout(() => { open = false }, 3000) }" class="fixed flex items-center justify-center top-0 right-0 w-full z-50">
      <div class="w-full max-w-sm m-2 py-3 px-4 overflow-hidden shadow-lg rounded-md flex items-center border ${shades[type.detail.type]}"
        x-show="open"
        x-transition:enter="transition ease-out duration-300"
        x-transition:enter-start="opacity-0 transform -translate-y-5"
        x-transition:enter-end="opacity-100 transform translate-y-0"
        x-transition:leave="transition ease-in duration-300"
        x-transition:leave-start="opacity-100 transform translate-y-0"
        x-transition:leave-end="opacity-0 transform -translate-y-5"
      >
      ${icons[type.detail.type]}
        <div class="ml-4 flex-1">
            <div class="text-lg text-gray-600 font-semibold capitalize">${type.detail.type}</div>
            <div class="text-sm">${type.detail.message}</div>
        </div>
        <div x-on:click="open = false" class="ml-4 text-gray-500 w-5 cursor-pointer hover:text-gray-900">
            <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M6 18L18 6M6 6l12 12" />
            </svg>
        </div>
      </div>
    </div>
    `;
  setTimeout(() => document.body.append(el), 100);
});

document.querySelectorAll("#blacklist form").forEach((el) => {
  el.addEventListener("submit", (e) => {
    e.preventDefault();
    location.hash = document.querySelector("#blacklist input[name=input]").value;
    checkBlacklist();
  });
});

function checkBlacklist() {
  let current = 0;
  document.querySelector("#blacklist form input[type=submit]").disabled = true;
  const input = document.querySelector("#blacklist input[name=input]").value;
  if (trim(input)) {
    document.querySelector("#blacklist-results .row").innerHTML = '<div class="col-12 text-center mt-3"><div class="spinner-border" role="status"><span class="sr-only">Loading...</span></div></div>';
    axios.post(`/domain/ip/${input}`).then((response) => {
      if (response.data) {
        const ip = response.data;
        if (ip) {
          console.log(blacklists);
          document.querySelector("#blacklist-results .row").innerHTML = "";
          blacklists.forEach((blacklist) => {
            axios
              .post("/blacklist", {
                ip,
                blacklist,
              })
              .then((response) => {
                current++;
                document.querySelector("#blacklist form input[type=submit]").value = `Checking (${current}/${blacklists.length})`;
                let listed = response.data ? true : false;
                let icon = "fa-check-circle text-success";
                let label_css = "bg-success";
                let label = "Not Listed";
                if (listed) {
                  icon = "fa-times-circle text-danger";
                  label_css = "bg-danger";
                  label = "Listed";
                }
                document.querySelector("#blacklist-results .row").insertAdjacentHTML(
                  "beforeend",
                  `<div class="col-12 col-lg-6 col-xl-4 mt-2">
                        <div class="border rounded p-2">
                            <div class="row">
                                <div class="col-8 d-flex align-items-center gap-5">
                                    <i class="fas ${icon} ml-1"></i>
                                    <div>${blacklist}</div>
                                </div>
                                <div class="col-4 text-right">
                                    <small class="${label_css} text-white px-2 py-1 rounded">${label}</small>
                                </div>
                            </div>
                        </div>
                    </div>`
                );
              })
              .finally(() => {
                if (current == blacklists.length) {
                  document.querySelector("#blacklist form input[type=submit]").disabled = false;
                  document.querySelector("#blacklist form input[type=submit]").value = document.querySelector("#blacklist form input[type=submit]").dataset.value;
                }
              });
          });
        } else {
          document.querySelector("#blacklist-results .row").innerHTML = '<div class="col-12 text-center">Invalid Input. Please try again!</div>';
        }
      }
    });
  }
}

document.querySelectorAll("#dmarc form").forEach((el) => {
  el.addEventListener("submit", (e) => {
    e.preventDefault();
    location.hash = document.querySelector("#dmarc input[name=input]").value;
    checkDmarc();
  });
});

function checkDmarc() {
  document.querySelector("#dmarc form input[type=submit]").disabled = true;
  const input = document.querySelector("#dmarc input[name=input]").value;
  if (trim(input)) {
    document.querySelector("#dmarc-results").innerHTML = '<div class="row"><div class="col-12 text-center mt-3"><div class="spinner-border" role="status"><span class="sr-only">Loading...</span></div></div></div>';
    axios.post(`/dmarc/${input}`).then((response) => {
      document.querySelector("#dmarc form input[type=submit]").disabled = false;
      if (response.data) {
        const records = response.data.split(";");
        if (records.length > 0) {
          let tbody = "";
          for (let i = 0; i < records.length; i++) {
            [type, value] = records[i].split("=");
            tbody += `
                <tr>
                  <th>${type}</th>
                  <td>${value}</td>
                  <td><img src="/${checkValidity(type, value) ? successImg : errorImg}" alt="validity-check"></td>
                  <td>${getDescription(type)}</td>
                </tr>
              `;
          }
          let html = `
              <div class="table-responsive">
                <table class="table table-bordered rounded">
                  <thead>
                    <tr>
                      <th scope="col">Tag</th>
                      <th scope="col">Value</th>
                      <th scope="col">Validity</th>
                      <th scope="col">Description</th>
                    </tr>
                  </thead>
                  <tbody>
                    ${tbody}
                  </tbody>
                </table>
              </div>
            `;
          document.getElementById("dmarc-results").innerHTML = html;
        }
      } else {
        document.querySelector("#dmarc-results").innerHTML = `
            <div class="row">
              <div class="col-12 text-center mt-3">
                <div class="d-flex align-items-center justify-content-center">
                  <img src="/${errorImg}" alt="error">
                  <p class="m-0 ml-2">DMARC Record Not Found</p>
                </div>
              </div>
            </div>
          `;
      }
    });
  }
}

document.querySelectorAll("#email-headers form").forEach((el) => {
  el.addEventListener("submit", (e) => {
    e.preventDefault();
    let raw = el.querySelector("textarea").value;
    let headers = extractEmailHeaders(raw);
    let headerKeys = Object.keys(headers);
    let tbody = "";
    for (let i = 0; i < headerKeys.length; i++) {
      tbody += `
        <tr>
          <th>${headerKeys[i]}</th>
          <td>${headers[headerKeys[i]]}</td>
        </tr>
      `;
    }
    let html = `
      <div class="table-responsive">
        <table class="table table-bordered rounded">
          <thead>
            <tr>
              <th scope="col">Tag</th>
              <th scope="col">Value</th>
            </tr>
          </thead>
          <tbody>
            ${tbody}
          </tbody>
        </table>
      </div>
    `;
    document.getElementById("email-headers-results").innerHTML = html;
  });
});

function extractEmailHeaders(emailContent) {
  const lines = emailContent.split("\n");
  let headers = {};
  let headerKey = "";
  let headerValue = "";
  let inHeaders = true;
  for (let line of lines) {
    if (inHeaders) {
      // Check if line is empty which means headers section is done
      if (line.trim() === "") {
        inHeaders = false;
        continue;
      }
      // Check for multiline headers
      if (line.startsWith(" ") || line.startsWith("\t")) {
        headers[headerKey] += " " + line.trim();
      } else {
        // Split the line into header key and value
        const [key, ...valueParts] = line.split(":");
        headerKey = key.trim();
        headerValue = valueParts.join(":").trim();
        headers[headerKey] = headerValue.replace("<", "&lt;").replace(">", "&gt;");
      }
    }
  }
  return headers;
}

function getDescription(type) {
  type = type.trim();
  const tags = JSON.parse('{"v":{"description":"Version of the DMARC protocol being used","example":"v=DMARC1"},"p":{"description":"Policy to be applied by the receiving mail server","example":"p=quarantine","possible_values":["none","quarantine","reject"]},"rua":{"description":"URI where aggregate feedback reports should be sent","example":"rua=mailto:aggrep@example.com"},"ruf":{"description":"URI where forensic (failure) reports should be sent","example":"ruf=mailto:forensic@example.com"},"sp":{"description":"Override policy for subdomains","example":"sp=reject","possible_values":["none","quarantine","reject"]},"adkim":{"description":"Alignment mode for DKIM (DomainKeys Identified Mail)","example":"adkim=r","possible_values":["r","s"]},"aspf":{"description":"Alignment mode for SPF (Sender Policy Framework)","example":"aspf=s","possible_values":["r","s"]},"pct":{"description":"Percentage of messages to which the DMARC policy is applied","example":"pct=100"},"fo":{"description":"Failure options for DMARC failures","example":"fo=1","possible_values":["0","1","d"]},"rf":{"description":"Report format for feedback reports","example":"rf=afrf","possible_values":["afrf","iodef"]},"ri":{"description":"Request to receivers to generate aggregate reports separated by no more than the requested number of seconds.","example":"ri=86400"}}');
  if (tags[type]) {
    return tags[type].description;
  }
}

function checkValidity(type, value) {
  type = type.trim();
  value = value.toLowerCase().trim();
  switch (type) {
    case "v":
      return value == "dmarc1";
    case "p":
      return ["none", "quarantine", "reject"].includes(value);
    case "sp":
      return ["none", "quarantine", "reject"].includes(value);
    case "adkim":
      return ["r", "s"].includes(value);
    case "aspf":
      return ["r", "s"].includes(value);
    case "pct":
      return parseInt(value) >= 0 && parseInt(value) <= 100;
    case "fo":
      return ["0", "1", "d"].includes(value);
    case "rf":
      return ["afrf", "iodef"].includes(value);
    case "rua":
      return isValidUri(value);
    case "ruf":
      return isValidUri(value);
    case "ri":
      return parseInt(value) >= 0 && parseInt(value) <= 4294967295;
  }
  return false;
}

function isValidUri(uri) {
  var uriPattern = /^(?:(?:[a-z]+:)?\/\/)?(?:\S+(?::\S*)?@)?(?:(?!-)[A-Za-z0-9-]{1,63}(?:(?:\.(?!-)[A-Za-z0-9-]{1,63})+)?)(?::\d{1,5})?(?:\/|[/?]\S+)?$/;
  return uriPattern.test(uri);
}

if (location.hash) {
  let value = location.hash.replaceAll("#", "");
  if (location.pathname.includes("blacklist")) {
    document.querySelector("#blacklist input[name=input]").value = value;
    checkBlacklist();
  } else if (location.pathname.includes("dmarc")) {
    document.querySelector("#dmarc input[name=input]").value = value;
    checkDmarc();
  }
}
